============================
pybullet_planning
============================

.. start-badges

.. image:: https://img.shields.io/badge/License-MIT-blue.svg
    :target: https://github.com/yijiangh/pybullet_planning/blob/master/LICENSE
    :alt: License MIT

.. .. image:: https://travis-ci.org/yijiangh/pybullet_planning.svg?branch=master
..     :target: https://travis-ci.org/yijiangh/pybullet_planning
..     :alt: Travis CI

.. end-badges

.. Write project description

**pybullet_planning** is a suite of utility functions to facilitate robotic planning related research on the
`pybullet <https://github.com/bulletphysics/bullet3>`_ physics simulation engine.


========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   reference/index
   contributing
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
